@@ -5,38 +5,43 @@ use strict;
 use warnings;
 
 use base qw ( Exporter );
-our @EXPORT_OK = qw( detect get_categories add_clues_file );
+our @EXPORT_OK = qw( detect get_categories );
 
 use lib::abs;
 use JSON qw();
 
 my %_categories;
-my @_clues_file_list = ( lib::abs::path( './apps.json' )  );
 
 # List of multi per web page application categories
 my %MULTIPLE_APP_CATS = map { $_ => 1 } qw( 
     widgets analytics javascript-frameworks video-players
-    font-scripts miscellaneous advertising-networks payment-processors
+    font-scripts miscellaneous advertizing-networks
 );
 
 =head1 NAME
 
-WWW::Wappalyzer - Perl port of Wappalyzer (http://wappalyzer.com)
+WWW::Wappalyzer
 
 =head1 DESCRIPTION
 
-Uncovers the technologies used on websites: detects content management systems, web shops,
-web servers, JavaScript frameworks, analytics tools and many more.
+Perl port of Wappalyzer (http://wappalyzer.com). Uncovers the technologies used on websites:
+detects content management systems, web shops, web servers, JavaScript frameworks, 
+analytics tools and many more.
 
 Lacks 'version' and 'confidence' support of original Wappalyzer in favour of speed.
 
-Clues:      L<https://github.com/AliasIO/Wappalyzer/blob/master/src/apps.json>
+Clues:      https://github.com/ElbertF/Wappalyzer/blob/master/share/apps.json
 
-More info on Wappalyzer:  L<https://github.com/AliasIO/Wappalyzer>
+More info:  https://github.com/ElbertF/Wappalyzer/blob/master/README.md
+
+=head1 VERSION
+
+Version 0.01
 
 =cut
 
-our $VERSION = '0.18';
+our $VERSION = '0.01';
+
 
 =head1 SYNOPSIS
 
@@ -63,14 +68,11 @@ None by default.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 detect
-
-    my %detected = detect( %params )
+=head2 %detected = detect( %params )
 
 Tries to detect CMS, framework, etc for given html code, http headers, url.
 
 Available parameters:
-
     html    - html code of web page
     headers - hash ref to http headers list
     url     - url of web page
@@ -78,12 +80,10 @@ Available parameters:
               less cats => less cpu usage
 
 Returns the hash of detected applications by categorie:
-
-    (
-        cms  => [ 'Joomla' ],
-        'javascript-frameworks' => [ 'jQuery', 'jQuery UI' ],
-    )
-
+(
+    cms  => [ 'Joomla' ],
+    javascript-frameworks => [ 'jQuery', 'jQuery UI' ],
+)
 =cut
 
 sub detect {
@@ -94,7 +94,7 @@ sub detect {
     # Lazy load and process clues from JSON file
     _load_categories() unless scalar keys %_categories;
 
-    my @cats = $params{cats} && ( ref( $params{cats} ) || '' ) eq 'ARRAY'
+    my @cats = $params{cats} && ( ref( $params{cats} ) // '' ) eq 'ARRAY'
         ? @{ $params{cats} } : get_categories();
 
     my $headers_ref;
@@ -166,63 +166,56 @@ sub detect {
     return %detected;
 }
 
-=head2 get_categories
-
-    my @cats = get_categories()
+=head2 my @cats = get_categories( )
 
 Returns the array of all application categories.
 
 =cut
 
 sub get_categories {
-    # Lazy load and process clues from JSON files
+    # Lazy load and process clues from JSON file
     _load_categories() unless scalar keys %_categories;
 
     return keys %_categories;
 }
 
-# Loads and processes clues from JSON files
+# Loads and processes clues from JSON file
 sub _load_categories {
 
-    for my $clue_file ( @_clues_file_list ) {
-        open my $fh, '<', $clue_file
-            or die "Can not read clues file $clue_file.";
+    # JSON file got from
+    # https://github.com/ElbertF/Wappalyzer/blob/master/share/apps.json
 
-        local $/ = undef;
-        my $json = <$fh>;
-        close $fh;
+    open my $fh, '<', lib::abs::path( './apps.json' )
+        or die 'Can not read clues file.';
 
-        # Do not support "Optional fields"
-        $json =~ s{ \\\\; (?: version | confidence ) [^"]+? " }{"}xig;
+    local $/ = undef;
+    my $json = <$fh>;
+    close $fh;
 
-        # Replace html entities with oridinary symbols
-        $json =~ s{&gt;}{>}xig;
-        $json =~ s{&lt;}{<}xig;
+    # Do not support "Optional fields"
+    $json =~ s{ \\\\; (?: version | confidence ) [^"]+? " }{"}xig;
 
-        my $cfg_ref = eval { JSON::decode_json( $json ) };
+    my $cfg_ref = JSON::decode_json( $json );
 
-        die "Can't parse clue file $clue_file: $@" if $@;
+    my $cats_ref = $cfg_ref->{categories}
+        or die 'Broken clues file. Can not find categories.';
 
-        my $cats_ref = $cfg_ref->{categories}
-            or die "Broken clues file $clue_file. Can not find categories.";
+    my $apps_ref = $cfg_ref->{apps}
+        or die 'Broken clues file. Can not find applications.';
 
-        my $apps_ref = $cfg_ref->{apps}
-            or die "Broken clues file $clue_file. Can not find applications.";
+    # Process apps
+    while ( my ( $app, $app_ref ) = each %$apps_ref ) {
 
-        # Process apps
-        while ( my ( $app, $app_ref ) = each %$apps_ref ) {
+        my $new_app_ref = _process_app_clues( $app, $app_ref ) or next;
 
-            my $new_app_ref = _process_app_clues( $app, $app_ref ) or next;
+        my @cats = @{ $app_ref->{cats} } or next;
 
-            my @cats = @{ $app_ref->{cats} } or next;
+        $new_app_ref->{multi_cat} = 1 if @cats > 1;
 
-            $new_app_ref->{multi_cat} = 1 if @cats > 1;
+        for my $cat_id ( @cats ) {
+            my $cat = $cats_ref->{ $cat_id } or next;
 
-            for my $cat_id ( @cats ) {
-                my $cat = $cats_ref->{ $cat_id } or next;
-
-                push @{ $_categories{ $cat } }, $new_app_ref;
-            }
+            push @{ $_categories{ $cat } }, $new_app_ref;
         }
     }
 }
@@ -237,10 +230,9 @@ sub _process_app_clues {
     my @html_re;
     # Precompile regexps
     for my $field ( @fields ) {
-        my $re_ref = $app_ref->{ $field };
-        my @re_list =   !ref $re_ref ? _escape_re( $re_ref )
-            : ref $re_ref eq 'ARRAY' ? ( map { _escape_re( $_ ) } @$re_ref )
-            : () ;
+        my $re_ref = $app_ref->{$field};
+        my @re_list = !ref $re_ref ? $re_ref
+            : ref $re_ref eq 'ARRAY' ? @$re_ref : () ;
 
         if ( $field eq 'html' ) {
             push @html_re, map { qr/(?-x:$_)/ } @re_list;
@@ -260,23 +252,21 @@ sub _process_app_clues {
         elsif ( $field eq 'meta' ) {
             for my $key ( keys %$re_ref ) {
                 my $name_re = qr{ name \s* = \s* ["']? $key ["']? }x;
-                my $re = _escape_re( $re_ref->{$key} );
-                $re = qr/$re/;
-                my $content_re = qr{ content \s* = \s* ["'] (?-x:[^"']*$re[^"']*) ["'] }x;
+                my $re = qr/$re_ref->{$key}/;
+                my $content_re = qr{ content= ["'] (?-x:[^"']*$re[^"']*) ["'] }x;
 
                 push @html_re, qr/
                     < \s* meta \s+
                     (?:
                           (?: $name_re    \s+ $content_re )
-                        # | (?: $content_re \s+ $name_re    ) # hangs sometimes
+                        | (?: $content_re \s+ $name_re    )
                     )
                 /x;
             }
         }
         elsif ( $field eq 'headers' ) {
             for my $key ( keys %$re_ref ) {
-                my $re = _escape_re( $re_ref->{$key} );
-                $new_app_ref->{headers_re}{ lc $key } = qr/$re/;
+                $new_app_ref->{headers_re}{ lc $key } = qr/$re_ref->{$key}/;
             }
         }
     }
@@ -290,43 +280,6 @@ sub _process_app_clues {
     return $new_app_ref;
 }
 
-# Escape special symbols in regexp string of config file
-sub _escape_re {
-    my ( $re ) = @_;
-    
-    # Escape { } braces
-    #$re =~ s/ ([{}]) /[$1]/xig;
-
-    # Escape [^]
-    $re =~ s{\Q[^]\E}{[\\^]}ig;
-
-    # Escape \\1
-    $re =~ s{\Q\1\E}{\\\\1}ig;
-
-    # Escape (?!
-    $re =~ s{[(][?][!]}{([?]!}ig; 
- 
-    return $re;
-}
-
-=head2 add_clues_file
-
-    add_clues_file( $filepath )
-
-Puts additional clues file to a list of processed clues files.
-See apps.json as format sample.
-
-=cut
-
-sub add_clues_file {
-    my ( $filepath ) = @_;
-
-    push @_clues_file_list, $filepath;
-
-    # just clear out categories to lazy load later
-    %_categories = ();
-}
-
 =head1 AUTHOR
 
 Alexander Nalobin, C<< <alexander at nalobin.ru> >>
@@ -349,10 +302,6 @@ You can also look for information at:
 
 =over 4
 
-=item * GitHub
-
-L<https://github.com/nalobin/WWW-Wappalyzer>
-
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Wappalyzer>
@@ -377,7 +326,7 @@ L<http://search.cpan.org/dist/WWW-Wappalyzer/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2015 Alexander Nalobin.
+Copyright 2013 Alexander Nalobin.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
